package com.yidianling.dynamic.trendList;

import android.view.View;

import com.yidianling.dynamic.model.ZanResult;
import com.yidianling.dynamic.model.TopicListDataBean;
import com.yidianling.dynamic.model.TrendsListBean;

import java.util.List;

/**
 * Created by Jim on 2017/9/26 0026.
 */

public interface ITrendsListView {
    void showLoadingDialog(boolean isNeedShowLoading);
    void hideLoadingView();
    void hideRefreshProgress();
    void showTrendsListView(List<TrendsListBean.Trend> data);
    /**
     * 更新banner数据
     * @param banner
     */
    void showBanner(List<TrendsListBean.Banner> banner);
    void showTrendsErrorView(Throwable e);
    void showRecommendTopicView(TopicListDataBean topicListDatas);
    void showRecommendTopicErrorView(Throwable e);
    void showLikedView(View view, int position, ZanResult zanResultBaseBean, List<TrendsListBean.Trend> mDatas);
    void showDisLikeView(View view, int position, ZanResult zanResultBaseBean, List<TrendsListBean.Trend> mDatas);
    void showTopTrendsView(List<TrendsListBean.ExtData> datas);
    void showToast(String msg);
    void showLikeActionFailed();

}